@@ -13,7 +13,7 @@ const plugin: JupyterFrontEndPlugin<void> = {
   id: 'serialhub:plugin',
   autoStart: true,
   activate: (app: JupyterFrontEnd) => {
-    console.log('JupyterLab extension serialhub is activated!');
+    console.log('JupyterLab extension serialhub is NOW activated!');
   }
 };
 
